package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.IntegralProductMapper;
import com.ruoyi.system.domain.IntegralProduct;
import com.ruoyi.system.service.IIntegralProductService;

/**
 * 积分商品Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class IntegralProductServiceImpl implements IIntegralProductService 
{
    @Autowired
    private IntegralProductMapper integralProductMapper;

    /**
     * 查询积分商品
     * 
     * @param id 积分商品主键
     * @return 积分商品
     */
    @Override
    public IntegralProduct selectIntegralProductById(Long id)
    {
        return integralProductMapper.selectIntegralProductById(id);
    }

    /**
     * 查询积分商品列表
     * 
     * @param integralProduct 积分商品
     * @return 积分商品
     */
    @Override
    public List<IntegralProduct> selectIntegralProductList(IntegralProduct integralProduct)
    {
        return integralProductMapper.selectIntegralProductList(integralProduct);
    }

    /**
     * 新增积分商品
     * 
     * @param integralProduct 积分商品
     * @return 结果
     */
    @Override
    public int insertIntegralProduct(IntegralProduct integralProduct)
    {
        return integralProductMapper.insertIntegralProduct(integralProduct);
    }

    /**
     * 修改积分商品
     * 
     * @param integralProduct 积分商品
     * @return 结果
     */
    @Override
    public int updateIntegralProduct(IntegralProduct integralProduct)
    {
        return integralProductMapper.updateIntegralProduct(integralProduct);
    }

    /**
     * 批量删除积分商品
     * 
     * @param ids 需要删除的积分商品主键
     * @return 结果
     */
    @Override
    public int deleteIntegralProductByIds(Long[] ids)
    {
        return integralProductMapper.deleteIntegralProductByIds(ids);
    }

    /**
     * 删除积分商品信息
     * 
     * @param id 积分商品主键
     * @return 结果
     */
    @Override
    public int deleteIntegralProductById(Long id)
    {
        return integralProductMapper.deleteIntegralProductById(id);
    }
}
