package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.IntegralCate;
import com.ruoyi.system.service.IIntegralCateService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.IntegralProduct;
import com.ruoyi.system.service.IIntegralProductService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 积分商品Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/IntegralProduct")
public class IntegralProductController extends BaseController
{
    @Autowired
    private IIntegralProductService integralProductService;
    @Autowired
    private IIntegralCateService integralCateService;
    /**
     * 查询积分商品列表
     */
    @PreAuthorize("@ss.hasPermi('system:IntegralProduct:list')")
    @GetMapping("/list")
    public TableDataInfo list(IntegralProduct integralProduct)
    {
        startPage();
        List<IntegralProduct> list = integralProductService.selectIntegralProductList(integralProduct);
        for(IntegralProduct data:list){
            IntegralCate integralCate=integralCateService.selectIntegralCateById(data.getCateId());
            if(integralCate!=null){
                data.setCateName(integralCate.getTitle());
            }


        }
        return getDataTable(list);
    }

    /**
     * 导出积分商品列表
     */
    @PreAuthorize("@ss.hasPermi('system:IntegralProduct:export')")
    @Log(title = "积分商品", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, IntegralProduct integralProduct)
    {
        List<IntegralProduct> list = integralProductService.selectIntegralProductList(integralProduct);
        ExcelUtil<IntegralProduct> util = new ExcelUtil<IntegralProduct>(IntegralProduct.class);
        util.exportExcel(response, list, "积分商品数据");
    }

    /**
     * 获取积分商品详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:IntegralProduct:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(integralProductService.selectIntegralProductById(id));
    }

    /**
     * 新增积分商品
     */
    @PreAuthorize("@ss.hasPermi('system:IntegralProduct:add')")
    @Log(title = "积分商品", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody IntegralProduct integralProduct)
    {
        return toAjax(integralProductService.insertIntegralProduct(integralProduct));
    }

    /**
     * 修改积分商品
     */
    @PreAuthorize("@ss.hasPermi('system:IntegralProduct:edit')")
    @Log(title = "积分商品", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody IntegralProduct integralProduct)
    {
        return toAjax(integralProductService.updateIntegralProduct(integralProduct));
    }

    /**
     * 定时任务状态修改
     */
    @PreAuthorize("@ss.hasPermi('system:IntegralProduct:changeStatus')")
    @Log(title = "修改状态", businessType = BusinessType.UPDATE)
    @PutMapping("/changeStatus")
    public AjaxResult changeStatus(@RequestBody IntegralProduct integralProduct)
    {
        IntegralProduct newIntegralProduct = integralProductService.selectIntegralProductById(integralProduct.getId());
        newIntegralProduct.setStatus(integralProduct.getStatus());
        return toAjax(integralProductService.updateIntegralProduct(newIntegralProduct));
    }


    /**
     * 删除积分商品
     */
    @PreAuthorize("@ss.hasPermi('system:IntegralProduct:remove')")
    @Log(title = "积分商品", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(integralProductService.deleteIntegralProductByIds(ids));
    }
}
